@@ -325,11 +325,6 @@ $vals{1}{7}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ]
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
-$vals{1}{7}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{7}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
 [ #BRACKET FOR GROUP
 [ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
